@@ -27,27 +27,17 @@ LOGS_PATH = f'../{BASE_PATH}/debug'
 
 DB_PATH = f'{BASE_PATH}/app-data.db'
 
-TARGET_USERS_INPUT_PATH = f'udemy_gather_data/{TARGET_DIR}/input_data/target-users.json'
-
-TARGET_USERS_OUTPUT_PATH = f"udemy_gather_data/{TARGET_DIR}/output_data/target_users.json"
-TARGET_COURSES_OUTPUT_PATH = f"udemy_gather_data/{TARGET_DIR}/output_data/target-courses.json"
-
-SEED_DB_TARGET_USERS = TARGET_USERS_OUTPUT_PATH
-SEED_DB_ALL_USERS = f"udemy_gather_data/{TARGET_DIR}/output_data/all-users.json"
-
-SEED_DB_TARGET_COURSES = TARGET_COURSES_OUTPUT_PATH
-SEED_DB_ALL_COURSES = f"udemy_gather_data/{TARGET_DIR}/output_data/all-courses.json"
-
-K8_JOB_YAML = f'../k8s/jobs/udemy-bot-job.yaml'
 DOCKER_COMPOSE_YAML = f'docker-compose.yaml'
 DOCKER_COMPOSE_YAML_FOR_VIDEOS = f'composes'
-ACTIONS_PATH = f'udemy_gather_data/{TARGET_DIR}/output_data/actions.txt'
 WAIT_DURATION = 20
 WAIT_DURATION_SHORT = 10
 WAIT_DURATION_VERY_SHORT = 5
+WAIT_DURATION_VERY_VERY_SHORT = 2
 
 
 RETRY_ATTEMPTS_LOW = 3
 RETRY_ATTEMPTS_HIGH = 5
 
-SECONDS_IN_MINUTES = 60
\ No newline at end of file
+SECONDS_IN_MINUTES = 60
+
+MASTER_API_URL = "http://master-srv:4000" if IS_DOCKER else "http://localhost:4000"
