@@ -169,14 +169,28 @@ def read_json(path):
         return users
 
 
+def read_file(path):
+    with open(path, 'r') as fp:
+        data = fp.read()
+        return data
+
+
 def write_file(path, data):
     with open(path, 'w') as fp:
         fp.write(data)
 
+
 def write_html(path, data):
     with open(path, 'w', encoding="utf-8") as fp:
         fp.write(data)
 
+
+def read_html(path):
+    with open(path, 'r', encoding="utf-8") as fp:
+        data = fp.read()
+        return data
+
+
 def append_file(path, data):
     with open(path, 'a') as fp:
         fp.write(data)
@@ -192,8 +206,8 @@ def crash():
     return 5/0
 
 
-def wait_for_enter():
-    input("Press Enter To Continue...")
+def wait_for_enter(message="Press Enter To Continue..."):
+    input(message)
 
 
 HOUR_SECONDS = 3600
@@ -244,6 +258,7 @@ def str_to_datetime(when):
 def datetime_to_str(when):
     return when.strftime(datetime_format)
 
+
 def datetime_file_safe_format(when):
     fmt = '%Y-%m-%d_%H-%M-%S'
     return when.strftime(fmt)
@@ -347,11 +362,13 @@ def partition(pred, iterable):
             falses.append(item)
     return trues, falses
 
+
 def partition_by_percentage(percentage, iterable):
     N = len(iterable)
     split_point = round(N * percentage)
     return iterable[0:split_point], iterable[split_point:N]
 
+
 if __name__ == '__main__':
     # print(get_utc_time())
     # print(datetime.now())
